@@ -1,9 +1,10 @@
 //go:build tools
 
-package tools
+package main
 
 import (
 	_ "github.com/go-task/task/v3/cmd/task"
 	_ "github.com/golangci/golangci-lint/cmd/golangci-lint"
 	_ "gotest.tools/gotestsum"
+	_ "mvdan.cc/gofumpt"
 )
